==> haskell-stmonadtrans-0.3.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.3.3
id: STMonadTrans-0.3.3-GgzmslWSp0k3kAlplg5GYF
key: STMonadTrans-0.3.3-GgzmslWSp0k3kAlplg5GYF
license: BSD3
maintainer: josef.svenningsson@gmail.com
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and this causes
    Bad Things to happen (such as loss of referential transparency). Safe
    monads include the monads State, Reader, Writer, Maybe and
    combinations of their corresponding monad transformers.
category: Monads
author: Josef Svenningsson
exposed: True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
abi: 36bea1df4d544e2903c9e845ed3c83cf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/STMonadTrans-0.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/STMonadTrans-0.3.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/STMonadTrans-0.3.3
hs-libraries: HSSTMonadTrans-0.3.3-GgzmslWSp0k3kAlplg5GYF
depends:
    array-0.5.1.1 base-4.9.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.3.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.3.4
id: STMonadTrans-0.3.4-8cQrHWbnDEL30NLdJ0qlZ8
key: STMonadTrans-0.3.4-8cQrHWbnDEL30NLdJ0qlZ8
license: BSD3
maintainer: josef.svenningsson@gmail.com
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and this causes
    Bad Things to happen (such as loss of referential transparency). Safe
    monads include the monads State, Reader, Writer, Maybe and
    combinations of their corresponding monad transformers.
category: Monads
author: Josef Svenningsson
exposed: True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
abi: 1abc877e1d201f376d96c49e57334421
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/STMonadTrans-0.3.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/STMonadTrans-0.3.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/STMonadTrans-0.3.4
hs-libraries: HSSTMonadTrans-0.3.4-8cQrHWbnDEL30NLdJ0qlZ8
depends:
    array-0.5.1.1 base-4.9.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
